==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCNav/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import UCInfo from '../UCInfo/index'
import UCIntegral from '../UCIntegral/index'
import UCHoliday from '../UCHoliday/index'
import UCFavorite from '../UCFavorite/index'
import UCMedal from '../UCMedal/index'
import {en, zh} from '../../assets/language/language'
import Building from '../Building/index'

@inject('UCNavStore', 'ConfigStore')
@observer
class KaraUC extends Component {
    constructor(props) {
        super(props)
        this.contentRef = React.createRef()
        this.state = {
            showModal: false,
        }
        this.lang = props.ConfigStore.config.language === 'en' ? en : zh
    }

    componentDidMount() {
        const {match} = this.props
        if (match && match.params && match.params.type && match.params.type < 4) {
            this.selectTab(Number(match.params.type))
        } else {
            this.selectTab(0)
        }
    }

    componentWillReceiveProps(next) {
        if (this.props.match.params.type !== next.match.params.type) {
            if (next.match.params.type <4) {
                this.selectTab(Number(next.match.params.type))
            } else {
                this.selectTab(0)
            }
        }
    }

    selectTab = (index) => {
        if (this.props.UCNavStore.activeTab != index) {
            this.props.UCNavStore.setActiveTab(index)
        }
    }

    loadComponet() {
        const {UCNavStore} = this.props
        if (UCNavStore.activeTab === 0) {
            return <UCInfo lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 1) {
            return <UCMedal contentRef={this.contentRef} lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 2) {
            return <UCFavorite contentRef={this.contentRef} lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 3) {
            return <UCIntegral lang={this.lang}/>
        }
        // else if (UCNavStore.activeTab === 3) {
        //   return <UCHoliday lang={this.lang}/>
        // }
    }

    render() {
        const {lang} = this
        const {UCNavStore, ConfigStore} = this.props;
        const {disableAuth=[]} = ConfigStore.config
        //console.log("user center", ConfigStore.config)
        return (
            <div className={css.KaraUC} ref={this.contentRef}>
                <ul className="s-bg-container">
                  {disableAuth.includes('my_web.namecard') ? null : <li className={UCNavStore.activeTab === 0 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(0)
                    }}>
                        <i className='kuc-iconfont kuc-user s-primary'></i>{lang.userInfo}
                    </li>}
                  {disableAuth.includes('my_web.myMedal') ? null : <li className={UCNavStore.activeTab === 1 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(1)
                    }}>
                        <i className='kuc-iconfont kuc-wodexunzhang s-primary'></i>{lang.myBadge}
                    </li>}
                  {disableAuth.includes('my_web.myCollection') ? null : <li className={UCNavStore.activeTab === 2 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(2)
                    }}>
                        <i className='kuc-iconfont kuc-collect s-primary'></i>{lang.myCollect}
                    </li>}
                  {disableAuth.includes('my_web.myPoints') ? null : <li className={UCNavStore.activeTab === 3 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(3)
                    }}>
                        <i className='kuc-iconfont kuc-score s-primary'></i>{lang.myScore}
                    </li>}
                    {/* <li className={UCNavStore.activeTab === 4 ? 's-bg-menu active' : ''} onClick={()=>{this.selectTab(3)}}>
            <i className='kuc-iconfont kuc-holiday s-primary'></i>我的休假
          </li> */}
                  {disableAuth.includes('my_web.changePassword') ? null : <li className={UCNavStore.activeTab === 4 ? 's-bg-menu active' : ''}>
                        <i className='kuc-iconfont kuc-suo s-primary'></i>
                        <a href="https://chgpass.asiainfo.com/ " target="view_window">{lang.changePw}</a>
                    </li>}
                </ul>
                <div className={`s-bg-container ${css.content}`}>
                    {this.loadComponet()}
                </div>
            </div>
        )
    }
}

export default KaraUC

==> kara-uc-1.2.34.tgz: package/src/kara-uc/components/UCNav/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import UCInfo from '../UCInfo/index'
import UCIntegral from '../UCIntegral/index'
import UCHoliday from '../UCHoliday/index'
import UCFavorite from '../UCFavorite/index'
import UCMedal from '../UCMedal/index'
import {en, zh} from '../../assets/language/language'
import Building from '../Building/index'

@inject('UCNavStore', 'ConfigStore')
@observer
class KaraUC extends Component {
    constructor(props) {
        super(props)
        this.contentRef = React.createRef()
        this.state = {
            showModal: false,
        }
        this.lang = props.ConfigStore.config.language === 'en' ? en : zh
    }

    componentDidMount() {
        const {match} = this.props
        if (match && match.params && match.params.type && match.params.type < 4) {
            this.selectTab(Number(match.params.type))
        } else {
            this.selectTab(0)
        }
    }

    componentWillReceiveProps(next) {
        if (this.props.match.params.type !== next.match.params.type) {
            if (next.match.params.type <4) {
                this.selectTab(Number(next.match.params.type))
            } else {
                this.selectTab(0)
            }
        }
    }

    selectTab = (index) => {
        if (this.props.UCNavStore.activeTab != index) {
            this.props.UCNavStore.setActiveTab(index)
        }
    }

    loadComponet() {
        const {UCNavStore} = this.props
        if (UCNavStore.activeTab === 0) {
            return <UCInfo lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 1) {
            return <UCMedal contentRef={this.contentRef} lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 2) {
            return <UCFavorite contentRef={this.contentRef} lang={this.lang}/>
        }
        else if (UCNavStore.activeTab === 3) {
            return <UCIntegral lang={this.lang}/>
        }
        // else if (UCNavStore.activeTab === 3) {
        //   return <UCHoliday lang={this.lang}/>
        // }
    }

    render() {
        const {lang} = this
        const {UCNavStore, ConfigStore} = this.props;
        const {disableAuth=[], user} = ConfigStore.config
        console.log("user center", user)
        return (
            <div className={css.KaraUC} ref={this.contentRef}>
                <ul className="s-bg-container">
                  {disableAuth.includes('my_web.namecard') ? null : <li className={UCNavStore.activeTab === 0 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(0)
                    }}>
                        <i className='kuc-iconfont kuc-user s-primary'></i>{lang.userInfo}
                    </li>}
                  {disableAuth.includes('my_web.myMedal') ? null : <li className={UCNavStore.activeTab === 1 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(1)
                    }}>
                        <i className='kuc-iconfont kuc-wodexunzhang s-primary'></i>{lang.myBadge}
                    </li>}
                  {disableAuth.includes('my_web.myCollection') ? null : <li className={UCNavStore.activeTab === 2 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(2)
                    }}>
                        <i className='kuc-iconfont kuc-collect s-primary'></i>{lang.myCollect}
                    </li>}
                  {disableAuth.includes('my_web.myPoints') ? null : <li className={UCNavStore.activeTab === 3 ? 's-bg-menu active' : ''} onClick={() => {
                        this.selectTab(3)
                    }}>
                        <i className='kuc-iconfont kuc-score s-primary'></i>{lang.myScore}
                    </li>}
                    {/* <li className={UCNavStore.activeTab === 4 ? 's-bg-menu active' : ''} onClick={()=>{this.selectTab(3)}}>
            <i className='kuc-iconfont kuc-holiday s-primary'></i>我的休假
          </li> */}
                  {disableAuth.includes('my_web.changePassword') ? null : <li className={UCNavStore.activeTab === 4 ? 's-bg-menu active' : ''}>
                        <i className='kuc-iconfont kuc-suo s-primary'></i>
                        <a href={user && user.bgId && user.bgId === '30804' ? "http://office.asiainfo-sec.com/chgpassword/" : "https://chgpass.asiainfo.com/"}
                        target="view_window">{lang.changePw}</a>
                    </li>}
                </ul>
                <div className={`s-bg-container ${css.content}`}>
                    {this.loadComponet()}
                </div>
            </div>
        )
    }
}

export default KaraUC
